Domain Attention Mixing Network(DAMN)

# Method



### Citation   
```
@article{tilk2021damn,
  title={Domain Attention Mixing Network},
  author={Bence Tilk},
  journal={GitHub: https://github.com/tilkb/damn},
  year={2021}
}
```   